@@ -2,8 +2,7 @@
 #define _APPCHK_SYMBOLS_H
 
 #include "../elfchk/elfchk.h"
-#include "../tetj/tetj.h"
 
-extern int checksymbols(ElfFile *file, struct tetj_handle *journal, int modules);
+extern int checksymbols(ElfFile *file, int modules);
 
 #endif /* _APPCHK_SYMBOLS_H */
