@@ -8,6 +8,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <time.h>
+#include <arpa/inet.h>
 #include "rpmchk.h"
 #include "md5.h"
 #include "tagfuncs.h"
@@ -89,8 +90,8 @@ checkRpmIdx(RpmFile * file1, RpmHdrIndex * hidx, RpmIdxTagFuncRec Tags[],
 		      ntohl(hidx[i].offset), ntohl(hidx[i].count));
 	    tetj_testcase_info(journal, tetj_activity_count, tetj_tp_count,
 		               0, 0, 0, tmp_string);
-	    fprintf(stderr, "Error: %s\n", tmp_string);
-	    tetj_result(journal, tetj_activity_count, tetj_tp_count, TETJ_FAIL);
+	    fprintf(stderr, "Warning: %s\n", tmp_string);
+	    tetj_result(journal, tetj_activity_count, tetj_tp_count, TETJ_WARNING);
 	    tetj_purpose_end(journal, tetj_activity_count, tetj_tp_count); 
 	}
     }
@@ -407,6 +408,30 @@ checkRpmIdxPGP(RpmFile * file1, RpmHdrIndex * hidx,
     return fail;
 }
 
+/* Ensure LSB 3.0 compatibility */
+int
+checkRpmIdxSHA1HEADER(RpmFile * file1, RpmHdrIndex * hidx,
+		      struct tetj_handle *journal)
+{
+    return checkRpmIdxSHA1(file1, hidx, journal);
+}
+
+int
+checkRpmIdxDSAHEADER(RpmFile * file1, RpmHdrIndex * hidx,
+		     struct tetj_handle *journal)
+{
+    return checkRpmIdxDSA(file1, hidx, journal);
+}
+
+int
+checkRpmIdxRSAHEADER(RpmFile * file1, RpmHdrIndex * hidx,
+		     struct tetj_handle *journal)
+{
+    return checkRpmIdxRSA(file1, hidx, journal);
+}
+
+/* END OF: Ensure LSB 3.0 compatibility */
+
 int
 checkRpmIdxSHA1(RpmFile * file1, RpmHdrIndex * hidx,
 		      struct tetj_handle *journal)
